package Locale::CLDR::Ga::Any v0.25.0;
# This file auto generated
#	on Mon 21 Apr 11:02:43 pm GMT

use v5.18;
use mro 'c3';

use Moose;

extends('Locale::CLDR::Ga');

no Moose;
__PACKAGE__->meta->make_immutable;
